import { View, Text, RadioGroup, Picker, Image, Input, Radio, Label, ScrollView, Slot } from '@tarojs/components'
import Taro, { useDidShow, useRouter } from '@tarojs/taro';
import { useEffect, useState } from 'react';
import Form from '@/components/Form';
import FormItem from '@/components/Form/FormItem';
import AuthProfile from '@/components/Authorize/AuthProfile';
import { addDogList, addlication, getDogInfo } from '@/services/dogAPI';
import { handleFile } from '@/utils/request';
import { useModel } from '@/store';
import Button from '../../components/Button';

import './style.less'
import { getCardLicenseInfo } from '../../services/dogAPI';

export default (props) => {
  const { dogs, person } = useModel('userData')
  const [formData, setFormData] = useState()
  const value = useRouter();
  const { petId } = value.params

  const [dogDate, setDogDate] = useState({ immunizationDate: null, petBirthday: null, petSex: [], petType: [] })
  const [mainDog, setMainDog] = useState([])
  const [dogStatus, setDogStatus] = useState(true)
  const [renewalAndReissue, setRenewalAndReissue] = useState()

  const router = useRouter()
  const applyType = router.params.type || 'first'
  useEffect(() => {
    switch (applyType) {
      // case 'first':
      // break;
      case 'renewal':
        Taro.setNavigationBarTitle({
          title: '证件续期'
        })
        break;
      case 'reissue':
        Taro.setNavigationBarTitle({
          title: '证件补办'
        })
        break;


      default:
        break;
    }

  }, [applyType])
  useDidShow(() => {
    addDogList().then((res) => {
      setMainDog(res.records)
    })
  }, [])


  const getDogInfoFunction = (petId) => {

    getDogInfo(petId).then((e) => {
      setFormData(e)
      const sex = [{ value: e?.sex, text: e?.sex == 1 ? '雄' : '雌' }];
      const petType = [{ value: 0, name: e?.petType }];

      setDogDate({ ...dogDate, petBirthday: e?.birthday, petSex: sex, petType: petType, })
      console.log('test', e);

    })
  }
  const getMainDogChange = (value) => {
    console.log("🚀 ~ file: index.jsx ~ line 34 ~ getMainDogChange ~ value", value)
    const { petId } = value.detail.data
    if (applyType == 'renewal' || applyType == 'reissue') {
      setDogStatus(false)
      getDogInfoFunction(petId)
      getCardLicenseInfo(petId).then((res) => {
        console.log('狗子证件有效期', res);
        setRenewalAndReissue(res)
      })
    }
    if (applyType == 'first') {
      getCardLicenseInfo(petId).then((res) => {
        if (!res) {
          setDogStatus(false)
          getDogInfoFunction(petId)
        } else {
          setDogStatus(true)
          Taro.showModal({
            title: '提示',
            content: '当前狗狗已有证件，请勿重复申请！',
            showCancel: false,
            success: function (v) {
              if (v.confirm) {
                console.log('用户点击确定')
                Taro.navigateBack({
                  delta: 1
                })
              }
            }
          })


        }
      })
    }

  }

  const onDateChange = (type, value) => {
    console.log('dogDate', dogDate);

    switch (type) {
      case 'petSex':
        setDogDate({ ...dogDate, petSex: value })
        break;
      case 'petBirthday':
        setDogDate({ ...dogDate, petBirthday: value })
        break;
      case 'petType':
        setDogDate({ ...dogDate, petType: value })
        break;
      case 'immunizationDate':
        setDogDate({ ...dogDate, immunizationDate: value })
        break;
      default:
        break;
    }
  }

  const modeList = [
    {
      value: 1,
      text: '自取',
    },
    {
      value: 2,
      text: '邮寄',
    },
  ]

  // ...dogDate,
  const formSubmit = value => {
    if (applyType == 'renewal' || applyType == 'reissue') {
      addlication({ ...value, applyType, petId: formData.petId, originCardNo: renewalAndReissue?.cardNo }).then((res) => {
        console.log('dogInfo xinwe', res);
        Taro.showToast({
          title: '申请成功，等待审核',
          icon: 'none',
          duration: 1000
        })
        if (applyType == 'renewal') {
          Taro.navigateBack({
            delta: 1
          })
          return;
        } else {
          Taro.reLaunch({
            url: `/pages/payPage/index?id=${res.applyId}`
          })
        }

      })
    } else {
      addlication({ ...value, applyType, petId: formData.petId }).then((res) => {
        console.log('dogInfo xinwe', res);
        Taro.showToast({
          title: '申请成功，等待审核',
          icon: 'none',
          duration: 1000
        })
        if (applyType == 'renewal') {
          Taro.navigateBack({
            delta: 1
          })
          return;
        } else {
          Taro.reLaunch({
            url: `/pages/payPage/index?id=${res.applyId}`
          })
        }

      })
    }

  }

  const rules = {
    petName: [{ required: true, message: '请填写狗狗名称' }],
    petSex: [{ type: 'number', required: true, message: '请填写狗狗性别' }],
    petBirthday: [{ required: true, message: '请选择狗狗生日' }],
    petColor: [{ required: true, message: '请选择狗狗毛色' }],
    petType: [{ required: true, message: '请选择犬种类别' }],
    img1: [{ required: true, message: '请上传狗狗照片' }],
    immunizationDate: [{ required: true, message: '请上输入最近免疫时间' }],
    immunizationCode: [{ required: true, message: '请输入免疫证号' }],
    immunizationImg: [{ required: true, message: '请上传免疫图片' }],
    address: [{ required: true, message: '请输入详细地址' }],

  }

  return (
    <>
      <AuthProfile />
      <View class='page' >
        <Form onSubmit={formSubmit} rules={rules} >
          <mp-form  >
            <mp-cells >
              <FormItem title='犬主姓名' required>
                <View >{person?.nickName}</View>
              </FormItem>
              {
                applyType == 'first' ? <></>
                  :
                  <>
                    <FormItem title='证件号' required>
                      <View >{renewalAndReissue?.cardNo}</View>
                    </FormItem>
                    <FormItem title='有效期' required>
                      {
                        formData?.sex ?
                          <View >

                            {renewalAndReissue?.startDate}~{renewalAndReissue?.expireDate}</View>
                          :
                          <View></View>
                      }

                    </FormItem>
                  </>
              }

              <FormItem title='狗狗名称' required>
                <s-picker name='petName' rangeKey='name' rangeValue='value' range={mainDog} value={formData?.name} onChange={getMainDogChange} />
              </FormItem>
              <FormItem title='狗狗性别' required>
                <s-picker name='petSex' rangeKey='text' rangeValue='value' range={dogDate.petSex} value={formData?.sex} />
              </FormItem>
              <FormItem title='犬种' required>
                <s-picker name='petType' rangeKey='name' rangeValue='name' range={dogDate.petType} value={formData?.petType} />
              </FormItem>
              <FormItem title='生日' required>
                <Picker name='petBirthday' mode='date' value={dogDate.petBirthday} onChange={(e) => { onDateChange('petBirthday', e.detail.value) }}>
                  {dogDate?.petBirthday ? (
                    <View className='picker' >
                      {dogDate.petBirthday}
                    </View>
                  ) : <View style={{ color: '#858585' }}>请选择...</View>
                  }
                  {/* <View className='picker' style={!formData ? { "color": '#858585' } : {}}>
                    {dogDate.petBirthday}
                  </View> */}
                </Picker>
              </FormItem>
              <FormItem title='毛色' required>
                <Input name='petColor' placeholder='请输入毛色' value={formData?.color} />
              </FormItem>
              <FormItem title='狗狗照片' required>
                <uploader name='img1' onFile={handleFile} value={formData?.image} />
              </FormItem>
              <FormItem title='最近免疫日期' required>
                <Picker name='immunizationDate' mode='date' onChange={(e) => { onDateChange('immunizationDate', e.detail.value) }}>
                  {dogDate?.immunizationDate ? (
                    <View className='picker' >
                      {dogDate.immunizationDate}
                    </View>
                  ) : <View style={{ color: '#858585' }}>请选择...</View>
                  }

                </Picker>
              </FormItem>
              <FormItem title='免疫证号' required>
                <Input name='immunizationCode' placeholder='请输入免疫证号' />
              </FormItem>
              <FormItem title='免疫证明' required>
                <uploader name='immunizationImg' onFile={handleFile} />
              </FormItem>
              <FormItem title='详细地址' required>
                <Input name='address' placeholder='请输入详细地址' />
              </FormItem>
              {
                applyType == 'renewal' ? <></>
                  :
                  <FormItem title='申领方式' extClass=''>
                    <View className='radio-list'>
                      <RadioGroup name='applyMethod'>
                        {modeList.map((item, i) => {
                          return (
                            <Label className='radio-list__label' for={i} key={i}>
                              <Radio color='#FCD905' className='radio-list__radio' value={item.value} >{item.text}</Radio>
                            </Label>
                          )
                        })}
                      </RadioGroup>
                    </View>
                  </FormItem>
              }


            </mp-cells>
          </mp-form>
          <Button disabled={dogStatus} title='确定' />
        </Form>
      </View>
    </>
  )
}




